"""
The `~plasmapy.dispersion.numerical` subpackage contains functionality
associated with numerical dispersion solvers.
"""
__all__ = ["hollweg"]

from plasmapy.dispersion.numerical.hollweg_ import hollweg
